Summary:              Linux D-Bus Message Broker
Name:                 dbus-broker
Version:              35
Release:              5%{?dist}
License:              ASL 2.0
URL:                  https://github.com/bus1/dbus-broker
Source0:              https://github.com/bus1/dbus-broker/releases/download/v%{version}/dbus-broker-%{version}.tar.xz
Patch0001: https://github.com/bus1/dbus-broker/commit/f805f4114f33ddb61382f7d6989cc3f94e0f7f1a.patch
Patch0002: https://github.com/bus1/dbus-broker/commit/9c2d3e310bb40c6db2966570695e896b540e467e.patch
Patch0003: https://github.com/bus1/dbus-broker/commit/fedceff76af876d3069d4df2eedd0a974d16c3ff.patch
Patch0004: https://github.com/bus1/dbus-broker/commit/4fa73fd2dc8429ff0fbbda39bce8e8af92681b07.patch
BuildRequires:        gcc, meson
BuildRequires:        pkgconfig(audit), pkgconfig(expat), pkgconfig(dbus-1)
BuildRequires:        pkgconfig(libcap-ng), pkgconfig(libselinux), pkgconfig(libsystemd), pkgconfig(systemd)
BuildRequires:        glibc-devel, python3-docutils
Requires:             dbus-common
Requires(pre):        shadow-utils

%description
dbus-broker is an implementation of a message bus as defined by the D-Bus
specification. Its aim is to provide high performance and reliability, while
keeping compatibility to the D-Bus reference implementation. It is exclusively
written for Linux systems, and makes use of many modern features provided by
recent Linux kernel releases.

%prep
%setup -q

%build

%ifarch aarch64
%undefine _auto_set_build_flags
%global ourcflags %(echo %optflags | sed -e 's|-O2|-O|')

CFLAGS="${CFLAGS:-%{ourcflags}}" ; export CFLAGS ;
CXXFLAGS="${CXXFLAGS:-%{ourcflags}}" ; export CXXFLAGS ;
LDFLAGS="${LDFLAGS:-%{build_ldflags}}" ; export LDFLAGS ;
LT_SYS_LIBRARY_PATH="${LT_SYS_LIBRARY_PATH:-%_libdir:}" ; export LT_SYS_LIBRARY_PATH ;
CC="${CC:-%{__cc}}" ; export CC ;
CXX="${CXX:-%{__cxx}}" ; export CXX ;
%{__meson} \
  --buildtype=plain \
  --prefix=%{_prefix} \
  --libdir=%{_libdir} \
  --libexecdir=%{_libexecdir} \
  --bindir=%{_bindir} \
  --sbindir=%{_sbindir} \
  --includedir=%{_includedir} \
  --datadir=%{_datadir} \
  --mandir=%{_mandir} \
  --infodir=%{_infodir} \
  --localedir=%{_datadir}/locale \
  --sysconfdir=%{_sysconfdir} \
  --localstatedir=%{_localstatedir} \
  --sharedstatedir=%{_sharedstatedir} \
  --wrap-mode=%{__meson_wrap_mode} \
  --auto-features=%{__meson_auto_features} \
  %{_vpath_srcdir} %{_vpath_builddir} \
  -Dselinux=true -Daudit=true -Ddocs=true
%endif

%ifarch x86_64
%meson -Dselinux=true -Daudit=true -Ddocs=true
%endif

%ifarch loongarch64
CONFIGURE_OPTS=(
    -Daudit=true
    -Dselinux=true
    -Ddocs=true
    -Dsystem-console-users=gdm
    -Dlinux-4-17=true
)
%meson "${CONFIGURE_OPTS[@]}"
%endif

%meson_build

%install
%meson_install

%check
%meson_test

%pre
%global uid 81
/usr/sbin/groupadd -r -g %{uid} dbus 2>/dev/null || :
/usr/sbin/useradd -c 'System message bus' -u %{uid} -g %{uid} \
    -s /sbin/nologin -r -d '/' dbus 2> /dev/null || :

%post
%systemd_post dbus-broker.service
%systemd_user_post dbus-broker.service

%preun
%systemd_preun dbus-broker.service
%systemd_user_preun dbus-broker.service

%postun
%systemd_postun dbus-broker.service
%systemd_user_postun dbus-broker.service

%files
%license LICENSE
%doc AUTHORS
%{_bindir}/dbus-broker
%{_bindir}/dbus-broker-launch
%{_journalcatalogdir}/dbus-broker.catalog
%{_journalcatalogdir}/dbus-broker-launch.catalog
%{_unitdir}/dbus-broker.service
%{_userunitdir}/dbus-broker.service
%{_mandir}/man1/dbus-broker.1*
%{_mandir}/man1/dbus-broker-launch.1*

%changelog
* Wed Dec 25 2024 Tracker Robot <trackbot@opencloudos.tech> - 35-5
- Apply patches from rpm-tracker
- [Bug Fix] 4fa73fd2dc8429ff0fbbda39bce8e8af92681b07.patch: launch/policy: prevent linking policies on invalid gids
- [Bug Fix] fedceff76af876d3069d4df2eedd0a974d16c3ff.patch: launch/policy: deallocate unused records during import
- [Bug Fix] 9c2d3e310bb40c6db2966570695e896b540e467e.patch: util/misc: dont overload rvalue of get_seals()
- [Bug Fix] f805f4114f33ddb61382f7d6989cc3f94e0f7f1a.patch: bus/match: fix matching against arguments beyond the zeroth

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 35-4
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 35-3
- Rebuilt for loongarch release

* Tue Mar 19 2024 Wenlong Zhang <zhangwenlong@loongson.cn> - 35-2
- Add loongarch64 support for dbus-broker 

* Thu Jan 04 2024 Upgrade Robot <upbot@opencloudos.org> - 35-1
- Upgrade to version 35

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 31-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 31-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 31-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Nov 08 2022 Zhao Zhen <jeremiazhao@tencent.com> - 31-2
- fixed aarch64 testing error

* Tue Jul 19 2022 cunshunxia <cunshunxia@tencent.com> - 31-1
- initial build
